# Generated by roxygen2: do not edit by hand

export(addRasterMeta2Sat)
export(addSatDataLayer)
export(addSatLog)
export(addSatMetaEntry)
export(addSatMetaParam)
export(alignGeometry)
export(calcAtmosCorr)
export(calcDODN)
export(calcEarthSunDist)
export(calcPathRadDOS)
export(calcTOAIrradModel)
export(calcTOAIrradRadRef)
export(calcTOAIrradTable)
export(calcTopoCorr)
export(compFilePathLandsat)
export(compMetaLandsat)
export(convRad2BT)
export(convRad2Ref)
export(convRef2RadLinear)
export(convSC2Rad)
export(convSC2Ref)
export(countSatDataLayers)
export(createRasterMetaData)
export(createSatBCDE)
export(crop)
export(demTools)
export(extend)
export(getSatBCDE)
export(getSatBCDECalib)
export(getSatBCDEFromSpectrum)
export(getSatBCDEFromType)
export(getSatBCDESolar)
export(getSatBCDESolarCalib)
export(getSatBCDESres)
export(getSatBCDEThermal)
export(getSatBCDEThermalCalib)
export(getSatBCDEType)
export(getSatBID)
export(getSatBTK1)
export(getSatBTK2)
export(getSatBandInfo)
export(getSatCalib)
export(getSatDATE)
export(getSatDataLayer)
export(getSatDataLayers)
export(getSatESD)
export(getSatESUN)
export(getSatLMAX)
export(getSatLMIN)
export(getSatLNBR)
export(getSatLayerfromData)
export(getSatLog)
export(getSatMeta)
export(getSatMetaBCDETemplate)
export(getSatMetaLayer)
export(getSatPRAD)
export(getSatParam)
export(getSatProjection)
export(getSatRADA)
export(getSatRADM)
export(getSatREFA)
export(getSatREFM)
export(getSatRadMax)
export(getSatRadMin)
export(getSatRefMax)
export(getSatRefMin)
export(getSatRes)
export(getSatSAZM)
export(getSatSELV)
export(getSatSID)
export(getSatSZEN)
export(getSatSensor)
export(getSatSensorGroup)
export(getSatSensorInfo)
export(getSatSpectrum)
export(getSatType)
export(getSatXRes)
export(getSatYRes)
export(lutInfo)
export(lutInfoBCDEFromBID)
export(lutInfoBIDFromBCDE)
export(lutInfoBandsFromSID)
export(lutInfoRSRromSID)
export(lutInfoSGRPfromFilename)
export(lutInfoSIDfromFilename)
export(lutInfoSensorFromSID)
export(maskInvarFeatures)
export(plot)
export(satellite)
export(setSatBCDE)
export(sortFilesLandsat)
export(subset)
export(updateRasterMetaData)
exportClasses(Satellite)
exportClasses(SatelliteInfo)
exportClasses(SatelliteLayers)
exportClasses(SatelliteLog)
exportClasses(SatelliteMetaData)
exportMethods(brick)
exportMethods(stack)
if (packageVersion("raster") >= "3.5.2") importFrom(terra,crop,extend)

import(Rcpp)
import(methods)
import(raster)
importFrom(stats,mvfft)
importFrom(stats4,plot)
useDynLib(satellite, .registration = TRUE)
