#### Package downloads from the [RStudio CRAN Mirror](http://cran-logs.rstudio.com/)</b>

This month      | In total
--------------- | -----------
![month](http://cranlogs.r-pkg.org/badges/satellite) | ![total](http://cranlogs.r-pkg.org/badges/grand-total/satellite)

<hr>

# satellite
This smorgasbord provides a variety of functions which are useful 
for handling, manipulating and visualizing remote sensing data.

====

### Installation

For the stable release version of **satellite** use


```S
install.packages("satellite")
```


To install the development version use


```S
library(devtools)
install_github("environmentalinformatics-marburg/satellite", ref = "develop")
```


### Contact

Please file bug reports and feature requests at https://github.com/environmentalinformatics-marburg/satellite/issues