# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

insertMinReqRem <- function(anHs, anHt) {
    .Call(`_satellite_insertMinReqRem`, anHs, anHt)
}

seqC <- function(from_, to_, by_ = 1.0) {
    .Call(`_satellite_seqC`, from_, to_, by_)
}

ScatteringModel <- function(mnBandWls, dScatCoef) {
    .Call(`_satellite_ScatteringModel`, mnBandWls, dScatCoef)
}

